pub struct Shared<T: ?Sized + Send + Sync + 'static> { /* private fields */ }Expand description
Sized wrapper that lets the service and contribution registries store an Arc<dyn Trait>
without introducing a global service locator or stringly typed key.
Implementations